@@ -15,7 +15,7 @@ use vars qw(
   $VERSION $SF_URI $SF_PREFIX $SF_PROXY $SF_SOBJECT_URI $SF_URIM $SF_APIVERSION
 );
 
-$VERSION = '0.15';
+$VERSION = '0.16';
 
 $SF_PROXY       = 'https://www.salesforce.com/services/Soap/u/8.0';
 $SF_URI         = 'urn:partner.soap.sforce.com';
@@ -100,7 +100,10 @@ sub create {
     delete( $in{'type'} );
 
     my @elems;
+    # ensure that 'type' element is first
+    push @elems, SOAP::Data->prefix('sfons')->name('type' => $type)->type(WWW::Salesforce::Constants->type($type, 'type'));
     foreach my $key ( keys %in ) {
+        next if ($key eq 'type');
         push @elems,
           SOAP::Data->prefix('sfons')->name( $key => $in{$key} )
           ->type( WWW::Salesforce::Constants->type( $type, $key ) );
@@ -762,10 +765,15 @@ sub update {
         }
 
         my @elems;
+        # ensure that 'type' element is first
+        push @elems,
+            SOAP::Data->prefix('sfons')->name('type' => $type)
+            ->type(WWW::Salesforce::Constants->type($type, 'type'));
         push @elems,
           SOAP::Data->prefix($SF_PREFIX)->name( 'Id' => $id )
           ->type('sforce:ID');
         foreach my $key ( keys %in ) {
+            next if ($key eq 'type');
             push @elems,
               SOAP::Data->prefix($SF_PREFIX)->name( $key => $in{$key} )
               ->type( WWW::Salesforce::Constants->type( $type, $key ) );
@@ -822,7 +830,12 @@ sub upsert {
         my %in = %{$_};
 
         my @elems;
+        # ensure that 'type' element is first
+        push @elems,
+            SOAP::Data->prefix('sfons')->name('type' => $type)
+            ->type(WWW::Salesforce::Constants->type($type, 'type'));
         foreach my $key ( keys %in ) {
+            next if ($key eq 'type');
             push @elems,
               SOAP::Data->prefix($SF_PREFIX)->name( $key => $in{$key} )
               ->type( WWW::Salesforce::Constants->type( $type, $key ) );
